@@ -170,7 +170,7 @@ fn dependency(
     let source_id = SourceId::for_path(&root)?;
     let mut nested_paths = vec![];
     let mut warnings = vec![];
-    let features = Features::new(&[], config, &mut warnings)?;
+    let features = Features::new(&[], config, &mut warnings, source_id.is_path())?;
     let mut cx = Context::new(
         &mut deps,
         source_id,
@@ -265,7 +265,7 @@ fn git_dependency_root_from_package<'a>(
 #[allow(clippy::unwrap_used)]
 fn package_id(source_id: SourceId, package_root: &Path) -> Result<PackageId> {
     let metadata = MetadataCommand::new()
-        .manifest_path(package_root.join("Cargo.toml"))
+        .current_dir(package_root)
         .no_deps()
         .exec()?;
 
